==> beast-0.5.1.tar.gz: beast-0.5.1/beast-gtk/bstenum_arrays.c <==

/* Generated data (by glib-mkenums) */


/* --- bstmarker.h --- */
#include	"bstmarker.h"
/* BstMarkerType
 */
static GEnumValue bst_marker_type_values[] = {
  { BST_MARKER_NONE, "BST_MARKER_NONE", "none" },
  { BST_MARKER_RED, "BST_MARKER_RED", "red" },
  { BST_MARKER_GREEN, "BST_MARKER_GREEN", "green" },
  { BST_MARKER_BLUE, "BST_MARKER_BLUE", "blue" },
  { 0, NULL, NULL }
};


/* --- bstmenus.h --- */
#include	"bstmenus.h"
/* BstChoiceFlags
 */
static GFlagsValue bst_choice_flags_values[] = {
  { BST_CHOICE_TYPE_SEPARATOR, "BST_CHOICE_TYPE_SEPARATOR", "type-separator" },
  { BST_CHOICE_TYPE_TITLE, "BST_CHOICE_TYPE_TITLE", "type-title" },
  { BST_CHOICE_TYPE_TEXT, "BST_CHOICE_TYPE_TEXT", "type-text" },
  { BST_CHOICE_TYPE_ITEM, "BST_CHOICE_TYPE_ITEM", "type-item" },
  { BST_CHOICE_TYPE_SUBMENU, "BST_CHOICE_TYPE_SUBMENU", "type-submenu" },
  { BST_CHOICE_TYPE_MASK, "BST_CHOICE_TYPE_MASK", "type-mask" },
  { BST_CHOICE_FLAG_INSENSITIVE, "BST_CHOICE_FLAG_INSENSITIVE", "flag-insensitive" },
  { BST_CHOICE_FLAG_DEFAULT, "BST_CHOICE_FLAG_DEFAULT", "flag-default" },
  { BST_CHOICE_FLAG_MASK, "BST_CHOICE_FLAG_MASK", "flag-mask" },
  { 0, NULL, NULL }
};


/* --- bstqsampler.h --- */
#include	"bstqsampler.h"
/* BstQSamplerType
 */
static GFlagsValue bst_qsampler_type_values[] = {
  { BST_QSAMPLER_ACTIVE, "BST_QSAMPLER_ACTIVE", "active" },
  { BST_QSAMPLER_SELECTED, "BST_QSAMPLER_SELECTED", "selected" },
  { BST_QSAMPLER_PRELIGHT, "BST_QSAMPLER_PRELIGHT", "prelight" },
  { BST_QSAMPLER_MARK_MASK, "BST_QSAMPLER_MARK_MASK", "mark-mask" },
  { BST_QSAMPLER_REGION_MASK, "BST_QSAMPLER_REGION_MASK", "region-mask" },
  { BST_QSAMPLER_MARK, "BST_QSAMPLER_MARK", "mark" },
  { BST_QSAMPLER_MASK, "BST_QSAMPLER_MASK", "mask" },
  { BST_QSAMPLER_SKIP, "BST_QSAMPLER_SKIP", "skip" },
  { BST_QSAMPLER_NEEDS_DRAW, "BST_QSAMPLER_NEEDS_DRAW", "needs-draw" },
  { BST_QSAMPLER_DIRTY, "BST_QSAMPLER_DIRTY", "dirty" },
  { 0, NULL, NULL }
};

/* BstQSamplerDrawMode
 */
static GEnumValue bst_qsampler_draw_mode_values[] = {
  { BST_QSAMPLER_DRAW_CRANGE, "BST_QSAMPLER_DRAW_CRANGE", "crange" },
  { BST_QSAMPLER_DRAW_CSHAPE, "BST_QSAMPLER_DRAW_CSHAPE", "cshape" },
  { BST_QSAMPLER_DRAW_ZERO_SHAPE, "BST_QSAMPLER_DRAW_ZERO_SHAPE", "zero-shape" },
  { BST_QSAMPLER_DRAW_MINIMUM_LINE, "BST_QSAMPLER_DRAW_MINIMUM_LINE", "minimum-line" },
  { BST_QSAMPLER_DRAW_MIDDLE_LINE, "BST_QSAMPLER_DRAW_MIDDLE_LINE", "middle-line" },
  { BST_QSAMPLER_DRAW_MAXIMUM_LINE, "BST_QSAMPLER_DRAW_MAXIMUM_LINE", "maximum-line" },
  { BST_QSAMPLER_DRAW_MINIMUM_SHAPE, "BST_QSAMPLER_DRAW_MINIMUM_SHAPE", "minimum-shape" },
  { BST_QSAMPLER_DRAW_MAXIMUM_SHAPE, "BST_QSAMPLER_DRAW_MAXIMUM_SHAPE", "maximum-shape" },
  { 0, NULL, NULL }
};


/* --- bstradiotools.h --- */
#include	"bstradiotools.h"
/* BstRadioToolsFlags
 */
static GFlagsValue bst_radio_tools_flags_values[] = {
  { BST_RADIO_TOOLS_NONE, "BST_RADIO_TOOLS_NONE", "none" },
  { BST_RADIO_TOOLS_TOOLBAR, "BST_RADIO_TOOLS_TOOLBAR", "toolbar" },
  { BST_RADIO_TOOLS_PALETTE, "BST_RADIO_TOOLS_PALETTE", "palette" },
  { 0, NULL, NULL }
};


/* --- bstdefs.h --- */
#include	"bstdefs.h"
/* BstOps
 */
static GEnumValue bst_ops_values[] = {
  { BST_OP_NONE, "BST_OP_NONE", "none" },
  { BST_OP_PROJECT_NEW, "BST_OP_PROJECT_NEW", "project-new" },
  { BST_OP_PROJECT_OPEN, "BST_OP_PROJECT_OPEN", "project-open" },
  { BST_OP_PROJECT_MERGE, "BST_OP_PROJECT_MERGE", "project-merge" },
  { BST_OP_PROJECT_SAVE, "BST_OP_PROJECT_SAVE", "project-save" },
  { BST_OP_PROJECT_SAVE_AS, "BST_OP_PROJECT_SAVE_AS", "project-save-as" },
  { BST_OP_PROJECT_NEW_SONG, "BST_OP_PROJECT_NEW_SONG", "project-new-song" },
  { BST_OP_PROJECT_NEW_SNET, "BST_OP_PROJECT_NEW_SNET", "project-new-snet" },
  { BST_OP_PROJECT_NEW_MIDI_SYNTH, "BST_OP_PROJECT_NEW_MIDI_SYNTH", "project-new-midi-synth" },
  { BST_OP_PROJECT_CLOSE, "BST_OP_PROJECT_CLOSE", "project-close" },
  { BST_OP_PROJECT_PLAY, "BST_OP_PROJECT_PLAY", "project-play" },
  { BST_OP_PROJECT_STOP, "BST_OP_PROJECT_STOP", "project-stop" },
  { BST_OP_PROJECT_RACK_EDITOR, "BST_OP_PROJECT_RACK_EDITOR", "project-rack-editor" },
  { BST_OP_DIALOG_PREFERENCES, "BST_OP_DIALOG_PREFERENCES", "dialog-preferences" },
  { BST_OP_DIALOG_PROC_BROWSER, "BST_OP_DIALOG_PROC_BROWSER", "dialog-proc-browser" },
  { BST_OP_DIALOG_DEVICE_MONITOR, "BST_OP_DIALOG_DEVICE_MONITOR", "dialog-device-monitor" },
  { BST_OP_REBUILD, "BST_OP_REBUILD", "rebuild" },
  { BST_OP_PART_ADD, "BST_OP_PART_ADD", "part-add" },
  { BST_OP_PART_DELETE, "BST_OP_PART_DELETE", "part-delete" },
  { BST_OP_PART_EDITOR, "BST_OP_PART_EDITOR", "part-editor" },
  { BST_OP_WAVE_LOAD, "BST_OP_WAVE_LOAD", "wave-load" },
  { BST_OP_WAVE_DELETE, "BST_OP_WAVE_DELETE", "wave-delete" },
  { BST_OP_WAVE_EDITOR, "BST_OP_WAVE_EDITOR", "wave-editor" },
  { BST_OP_TRACK_ADD, "BST_OP_TRACK_ADD", "track-add" },
  { BST_OP_TRACK_DELETE, "BST_OP_TRACK_DELETE", "track-delete" },
  { BST_OP_UNDO_LAST, "BST_OP_UNDO_LAST", "undo-last" },
  { BST_OP_REDO_LAST, "BST_OP_REDO_LAST", "redo-last" },
  { BST_OP_EXIT, "BST_OP_EXIT", "exit" },
  { BST_OP_HELP_FAQ, "BST_OP_HELP_FAQ", "help-faq" },
  { BST_OP_HELP_KEYTABLE, "BST_OP_HELP_KEYTABLE", "help-keytable" },
  { BST_OP_HELP_RELEASE_NOTES, "BST_OP_HELP_RELEASE_NOTES", "help-release-notes" },
  { BST_OP_HELP_GSL_PLAN, "BST_OP_HELP_GSL_PLAN", "help-gsl-plan" },
  { BST_OP_HELP_QUICK_START, "BST_OP_HELP_QUICK_START", "help-quick-start" },
  { BST_OP_HELP_ABOUT, "BST_OP_HELP_ABOUT", "help-about" },
  { BST_OP_LAST, "BST_OP_LAST", "last" },
  { 0, NULL, NULL }
};

/* BstQuantizationType
 */
static GEnumValue bst_quantization_type_values[] = {
  { BST_QUANTIZE_NONE, "BST_QUANTIZE_NONE", "none" },
  { BST_QUANTIZE_NOTE_1, "BST_QUANTIZE_NOTE_1", "note-1" },
  { BST_QUANTIZE_NOTE_2, "BST_QUANTIZE_NOTE_2", "note-2" },
  { BST_QUANTIZE_NOTE_4, "BST_QUANTIZE_NOTE_4", "note-4" },
  { BST_QUANTIZE_NOTE_8, "BST_QUANTIZE_NOTE_8", "note-8" },
  { BST_QUANTIZE_NOTE_16, "BST_QUANTIZE_NOTE_16", "note-16" },
  { BST_QUANTIZE_NOTE_32, "BST_QUANTIZE_NOTE_32", "note-32" },
  { BST_QUANTIZE_NOTE_64, "BST_QUANTIZE_NOTE_64", "note-64" },
  { BST_QUANTIZE_NOTE_128, "BST_QUANTIZE_NOTE_128", "note-128" },
  { BST_QUANTIZE_TACT, "BST_QUANTIZE_TACT", "tact" },
  { 0, NULL, NULL }
};


/* Generated data ends here */

==> beast-0.5.2-rc2.tar.gz: beast-0.5.2-rc2/beast-gtk/bstenum_arrays.c <==

/* Generated data (by glib-mkenums) */


/* --- bstfiledialog.h --- */
#include	"bstfiledialog.h"
/* BstFileDialogMode
 */
static GEnumValue bst_file_dialog_mode_values[] = {
  { BST_FILE_DIALOG_OPEN_PROJECT, "BST_FILE_DIALOG_OPEN_PROJECT", "open-project" },
  { BST_FILE_DIALOG_MERGE_PROJECT, "BST_FILE_DIALOG_MERGE_PROJECT", "merge-project" },
  { BST_FILE_DIALOG_SAVE_PROJECT, "BST_FILE_DIALOG_SAVE_PROJECT", "save-project" },
  { BST_FILE_DIALOG_LOAD_WAVE, "BST_FILE_DIALOG_LOAD_WAVE", "load-wave" },
  { BST_FILE_DIALOG_LOAD_WAVE_LIB, "BST_FILE_DIALOG_LOAD_WAVE_LIB", "load-wave-lib" },
  { BST_FILE_DIALOG_MODE_MASK, "BST_FILE_DIALOG_MODE_MASK", "mode-mask" },
  { BST_FILE_DIALOG_ALLOW_DIRS, "BST_FILE_DIALOG_ALLOW_DIRS", "allow-dirs" },
  { BST_FILE_DIALOG_FLAG_MASK, "BST_FILE_DIALOG_FLAG_MASK", "flag-mask" },
  { 0, NULL, NULL }
};


/* --- bstmarker.h --- */
#include	"bstmarker.h"
/* BstMarkerType
 */
static GEnumValue bst_marker_type_values[] = {
  { BST_MARKER_NONE, "BST_MARKER_NONE", "none" },
  { BST_MARKER_RED, "BST_MARKER_RED", "red" },
  { BST_MARKER_GREEN, "BST_MARKER_GREEN", "green" },
  { BST_MARKER_BLUE, "BST_MARKER_BLUE", "blue" },
  { 0, NULL, NULL }
};


/* --- bstmenus.h --- */
#include	"bstmenus.h"
/* BstChoiceFlags
 */
static GFlagsValue bst_choice_flags_values[] = {
  { BST_CHOICE_TYPE_SEPARATOR, "BST_CHOICE_TYPE_SEPARATOR", "type-separator" },
  { BST_CHOICE_TYPE_TITLE, "BST_CHOICE_TYPE_TITLE", "type-title" },
  { BST_CHOICE_TYPE_TEXT, "BST_CHOICE_TYPE_TEXT", "type-text" },
  { BST_CHOICE_TYPE_ITEM, "BST_CHOICE_TYPE_ITEM", "type-item" },
  { BST_CHOICE_TYPE_SUBMENU, "BST_CHOICE_TYPE_SUBMENU", "type-submenu" },
  { BST_CHOICE_TYPE_MASK, "BST_CHOICE_TYPE_MASK", "type-mask" },
  { BST_CHOICE_FLAG_INSENSITIVE, "BST_CHOICE_FLAG_INSENSITIVE", "flag-insensitive" },
  { BST_CHOICE_FLAG_DEFAULT, "BST_CHOICE_FLAG_DEFAULT", "flag-default" },
  { BST_CHOICE_FLAG_MASK, "BST_CHOICE_FLAG_MASK", "flag-mask" },
  { 0, NULL, NULL }
};


/* --- bstqsampler.h --- */
#include	"bstqsampler.h"
/* BstQSamplerType
 */
static GFlagsValue bst_qsampler_type_values[] = {
  { BST_QSAMPLER_ACTIVE, "BST_QSAMPLER_ACTIVE", "active" },
  { BST_QSAMPLER_SELECTED, "BST_QSAMPLER_SELECTED", "selected" },
  { BST_QSAMPLER_PRELIGHT, "BST_QSAMPLER_PRELIGHT", "prelight" },
  { BST_QSAMPLER_MARK_MASK, "BST_QSAMPLER_MARK_MASK", "mark-mask" },
  { BST_QSAMPLER_REGION_MASK, "BST_QSAMPLER_REGION_MASK", "region-mask" },
  { BST_QSAMPLER_MARK, "BST_QSAMPLER_MARK", "mark" },
  { BST_QSAMPLER_MASK, "BST_QSAMPLER_MASK", "mask" },
  { BST_QSAMPLER_SKIP, "BST_QSAMPLER_SKIP", "skip" },
  { BST_QSAMPLER_NEEDS_DRAW, "BST_QSAMPLER_NEEDS_DRAW", "needs-draw" },
  { BST_QSAMPLER_DIRTY, "BST_QSAMPLER_DIRTY", "dirty" },
  { 0, NULL, NULL }
};

/* BstQSamplerDrawMode
 */
static GEnumValue bst_qsampler_draw_mode_values[] = {
  { BST_QSAMPLER_DRAW_CRANGE, "BST_QSAMPLER_DRAW_CRANGE", "crange" },
  { BST_QSAMPLER_DRAW_CSHAPE, "BST_QSAMPLER_DRAW_CSHAPE", "cshape" },
  { BST_QSAMPLER_DRAW_ZERO_SHAPE, "BST_QSAMPLER_DRAW_ZERO_SHAPE", "zero-shape" },
  { BST_QSAMPLER_DRAW_MINIMUM_LINE, "BST_QSAMPLER_DRAW_MINIMUM_LINE", "minimum-line" },
  { BST_QSAMPLER_DRAW_MIDDLE_LINE, "BST_QSAMPLER_DRAW_MIDDLE_LINE", "middle-line" },
  { BST_QSAMPLER_DRAW_MAXIMUM_LINE, "BST_QSAMPLER_DRAW_MAXIMUM_LINE", "maximum-line" },
  { BST_QSAMPLER_DRAW_MINIMUM_SHAPE, "BST_QSAMPLER_DRAW_MINIMUM_SHAPE", "minimum-shape" },
  { BST_QSAMPLER_DRAW_MAXIMUM_SHAPE, "BST_QSAMPLER_DRAW_MAXIMUM_SHAPE", "maximum-shape" },
  { 0, NULL, NULL }
};


/* --- bstradiotools.h --- */
#include	"bstradiotools.h"
/* BstRadioToolsFlags
 */
static GFlagsValue bst_radio_tools_flags_values[] = {
  { BST_RADIO_TOOLS_NONE, "BST_RADIO_TOOLS_NONE", "none" },
  { BST_RADIO_TOOLS_TOOLBAR, "BST_RADIO_TOOLS_TOOLBAR", "toolbar" },
  { BST_RADIO_TOOLS_PALETTE, "BST_RADIO_TOOLS_PALETTE", "palette" },
  { 0, NULL, NULL }
};


/* --- bstdefs.h --- */
#include	"bstdefs.h"
/* BstActionRegions
 */
static GFlagsValue bst_action_regions_values[] = {
  { BST_ACTION_NONE, "BST_ACTION_NONE", "none" },
  { BST_ACTION_APP_FIRST, "BST_ACTION_APP_FIRST", "app-first" },
  { BST_ACTION_WAVE_FIRST, "BST_ACTION_WAVE_FIRST", "wave-first" },
  { BST_ACTION_PART_FIRST, "BST_ACTION_PART_FIRST", "part-first" },
  { BST_ACTION_TRACK_FIRST, "BST_ACTION_TRACK_FIRST", "track-first" },
  { 0, NULL, NULL }
};

/* BstQuantizationType
 */
static GEnumValue bst_quantization_type_values[] = {
  { BST_QUANTIZE_NONE, "BST_QUANTIZE_NONE", "none" },
  { BST_QUANTIZE_NOTE_1, "BST_QUANTIZE_NOTE_1", "note-1" },
  { BST_QUANTIZE_NOTE_2, "BST_QUANTIZE_NOTE_2", "note-2" },
  { BST_QUANTIZE_NOTE_4, "BST_QUANTIZE_NOTE_4", "note-4" },
  { BST_QUANTIZE_NOTE_8, "BST_QUANTIZE_NOTE_8", "note-8" },
  { BST_QUANTIZE_NOTE_16, "BST_QUANTIZE_NOTE_16", "note-16" },
  { BST_QUANTIZE_NOTE_32, "BST_QUANTIZE_NOTE_32", "note-32" },
  { BST_QUANTIZE_NOTE_64, "BST_QUANTIZE_NOTE_64", "note-64" },
  { BST_QUANTIZE_NOTE_128, "BST_QUANTIZE_NOTE_128", "note-128" },
  { BST_QUANTIZE_TACT, "BST_QUANTIZE_TACT", "tact" },
  { 0, NULL, NULL }
};


/* Generated data ends here */
